/*
 * Copyright (C) 2013 HERE Global B.V. All rights reserved.
 * This software, including documentation, is protected by copyright controlled by
 * HERE Global B.V. (“Software”). All rights are reserved. Copying, including reproducing,
 * storing, adapting or translating, any or all of this material requires the prior
 * written consent of HERE Global B.V. You may use this
 * Software in accordance with the terms and conditions defined in the
 * HERE Location Platform Services Terms and Conditions, available at
 * http://developer.here.com/terms-conditions-base
 *
 * As an additional permission to the above, you may distribute Software,
 * in object code format as part of an Application, according to, and subject to, terms and
 * conditions defined in the Tizen Software Development kit (“SDK”) License Agreement.
 * You may distribute such object code format Application under terms of your choice,
 * provided that the header and source files of the Software have not been modified.
 */

#ifndef CATEGORIES_REPLY_H_
#define CATEGORIES_REPLY_H_

#include "finder/BaseFinderReply.h"
#include "finder/CategoriesQuery.h"

HERE_MAPS_BEGIN_NAMESPACE

/**
 * This class encapsulates a response to a discovery query. The response is a
 * page of link objects, each containing information about one place. It also
 * includes a link to the next page of results, if available.
 *
 * \ingroup finder
 */
class EXPORT_API CategoriesReply : public BaseFinderReply
{
public:

    /**
     * This is the default constructor.
     */
    CategoriesReply();

    /**
     * This is the (virtual) destructor.
     */
    virtual ~CategoriesReply();

    /**
     * This method retrieves a list of search result items that can lead an
     * application user to detailed information about specific places.
     *
     * @return A vector of instances of <code>SearchItem</code> which represent
     *       individual search results.
     */
    CategoryList GetCategoryList() const;

private:
    void SetCategoryList(const CategoryList&);

private:
    HERE_MAPS_NO_COPY_NO_ASSIGN(CategoriesReply);

    virtual bool OnDataReceived(const unsigned char* pBuffer, size_t uSize);

    class CategoriesReplyImpl;
    CategoriesReplyImpl* m_pImpl;

    friend class JsonParser;
};

HERE_MAPS_END_NAMESPACE

#endif // CATEGORIES_REPLY_H_
